CountryData class

Utility class for managing country data and operations

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

findAllByPhoneCode(String phoneCode) List<Country>
Find all countries by phone code.
findByPhoneCode(String phoneCode) Country?
Find the first country by phone code.
getCountryByCode(String code) Country?
Get a country by its ISO code
getCountryByPhoneCode(String phoneCode) Country?
Get a country by its phone code
getSortedCountries(String getCountryName(String)) List<Country>
Get a sorted list of countries based on localized names
searchByPhoneCode(String phoneCode) List<Country>
Search countries by phone code only
searchCountries(String query, String getCountryName(String)) List<Country>
Search countries by name, code, or phone code

Constants

countries → const List<Country>
Complete list of all supported countries with phone codes