CountryFlag class

Country flag widget with emoji and SVG modes.

Inheritance

Constructors

CountryFlag({Key? key, required Country? country, CountryFlagMode mode = CountryFlagMode.emoji, CountryFlagStyle style = const CountryFlagStyle(), String unknownFlag = '🏳️', String svgUrlBuilder(String countryCode)?, CountryFlagSvgBuilder? svgBuilder, String? semanticsLabel})
const
CountryFlag.fromCountryCode(String countryCode, {Key? key, CountryFlagMode mode = CountryFlagMode.emoji, CountryFlagStyle style = const CountryFlagStyle(), String unknownFlag = '🏳️', String svgUrlBuilder(String countryCode)?, CountryFlagSvgBuilder? svgBuilder, String? semanticsLabel})
Create a flag by ISO country code.
factory
CountryFlag.fromCurrencyCode(String currencyCode, {Key? key, CountryFlagMode mode = CountryFlagMode.emoji, CountryFlagStyle style = const CountryFlagStyle(), String unknownFlag = '🏳️', String svgUrlBuilder(String countryCode)?, CountryFlagSvgBuilder? svgBuilder, String? semanticsLabel})
Create a flag by ISO 4217 currency code (for example USD).
factory
CountryFlag.fromLanguageCode(String languageCode, {Key? key, CountryFlagMode mode = CountryFlagMode.emoji, CountryFlagStyle style = const CountryFlagStyle(), String unknownFlag = '🏳️', String svgUrlBuilder(String countryCode)?, CountryFlagSvgBuilder? svgBuilder, String? semanticsLabel})
Create a flag by language code (for example en or pt-BR).
factory
CountryFlag.fromPhoneCode(String phoneCode, {Key? key, CountryFlagMode mode = CountryFlagMode.emoji, CountryFlagStyle style = const CountryFlagStyle(), String unknownFlag = '🏳️', String svgUrlBuilder(String countryCode)?, CountryFlagSvgBuilder? svgBuilder, String? semanticsLabel})
Create a flag by phone code (for example +1 or 44).
factory

Properties

country Country?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mode CountryFlagMode
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticsLabel String?
final
style CountryFlagStyle
final
svgBuilder CountryFlagSvgBuilder?
final
svgUrlBuilder String Function(String countryCode)?
final
unknownFlag String
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

defaultSvgUrlBuilder(String countryCode) String
Default SVG URL builder.
lookupByCurrencyCode(String currencyCode) Country?
Resolve country by currency code.
lookupByLanguageCode(String languageCode) Country?
Resolve country by language code.
lookupByPhoneCode(String phoneCode) Country?
Resolve country by phone code.