CountryFlagStyle class

Visual style for CountryFlag.

Annotations

Constructors

CountryFlagStyle({double size = 20, bool isCircle = false, BorderRadiusGeometry borderRadius = const BorderRadius.all(Radius.circular(6)), Color? backgroundColor, Color? borderColor, double borderWidth = 0, EdgeInsetsGeometry padding = EdgeInsets.zero, BoxFit fit = BoxFit.cover, TextStyle? emojiTextStyle})
const

Properties

backgroundColor Color?
final
borderColor Color?
final
borderRadius BorderRadiusGeometry
final
borderWidth double
final
emojiTextStyle TextStyle?
final
fit BoxFit
final
hashCode int
The hash code for this object.
no setterinherited
isCircle bool
final
padding EdgeInsetsGeometry
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
final

Methods

copyWith({double? size, bool? isCircle, BorderRadiusGeometry? borderRadius, Color? backgroundColor, Color? borderColor, double? borderWidth, EdgeInsetsGeometry? padding, BoxFit? fit, TextStyle? emojiTextStyle}) CountryFlagStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited