getCountryName method

  1. @override
String getCountryName(
  1. String countryCode
)
override

Get country name by country code

Returns the localized name for the given country code If the country code is not found, returns the code itself

Implementation

@override
String getCountryName(String countryCode) {
  return _countryNames[countryCode] ?? countryCode;
}