CountryPicker class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- CountryPicker
Constructors
-
CountryPicker({Key? key, Country? selectedCountry, required ValueChanged<
Country> onCountrySelected, String? labelText, String? hintText, bool showPhoneCodes = true, List<String> favorites = const [], List<String> exclude = const [], CountryFilter? countryFilter, VoidCallback? onOpened, VoidCallback? onClosed, ValueChanged<String> ? onSearchChanged, CountryPickerItemBuilder? itemBuilder, CountryPickerEmptySearchBuilder? emptySearchBuilder, CountryPickerModalHeaderBuilder? modalHeaderBuilder, double? bottomSheetWidth, bool moveAlongWithKeyboard = false, CountryPickerThemeData themeData = CountryPickerThemeData.dark, bool showFlags = true, bool showCountryCodes = true, bool adaptiveHeight = false, bool showSuggestedCountries = true, CountryPickerModalPresentation modalPresentation = CountryPickerModalPresentation.bottomSheet}) -
const
Properties
- adaptiveHeight → bool
-
final
- bottomSheetWidth → double?
-
final
- countryFilter → CountryFilter?
-
final
- emptySearchBuilder → CountryPickerEmptySearchBuilder?
-
final
-
exclude
→ List<
String> -
final
-
favorites
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hintText → String?
-
final
- itemBuilder → CountryPickerItemBuilder?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- labelText → String?
-
final
- modalHeaderBuilder → CountryPickerModalHeaderBuilder?
-
final
- modalPresentation → CountryPickerModalPresentation
-
final
- moveAlongWithKeyboard → bool
-
final
- onClosed → VoidCallback?
-
final
-
onCountrySelected
→ ValueChanged<
Country> -
final
- onOpened → VoidCallback?
-
final
-
onSearchChanged
→ ValueChanged<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedCountry → Country?
-
final
- showCountryCodes → bool
-
final
- showFlags → bool
-
final
- showPhoneCodes → bool
-
final
- showSuggestedCountries → bool
-
final
- themeData → CountryPickerThemeData
-
final
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< CountryPicker> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
builder(
) → CountryPickerBuilder - Create a builder for fluent API