CountryPickerThemeData class
Theme configuration for CountryPicker.
- Annotations
Constructors
- CountryPickerThemeData({Color? backgroundColor, Color? headerColor, Color? textColor, Color? accentColor, Color? searchFieldColor, Color? searchFieldBorderColor, Color? cursorColor, Color? hintTextColor, Color? hoverColor, double? borderRadius, TextStyle? textStyle, double? itemHeight, EdgeInsets? itemPadding, double? flagSize})
-
const
Properties
- accentColor → Color?
-
final
- backgroundColor → Color?
-
final
- borderRadius → double?
-
final
- cursorColor → Color?
-
final
- flagSize → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerColor → Color?
-
final
- hintTextColor → Color?
-
final
- hoverColor → Color?
-
final
- itemHeight → double?
-
final
- itemPadding → EdgeInsets?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchFieldBorderColor → Color?
-
final
- searchFieldColor → Color?
-
final
- textColor → Color?
-
final
- textStyle → TextStyle?
-
final
Methods
-
copyWith(
{Color? backgroundColor, Color? headerColor, Color? textColor, Color? accentColor, Color? searchFieldColor, Color? searchFieldBorderColor, Color? cursorColor, Color? hintTextColor, Color? hoverColor, double? borderRadius, TextStyle? textStyle, double? itemHeight, EdgeInsets? itemPadding, double? flagSize}) → CountryPickerThemeData -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- dark → const CountryPickerThemeData
- light → const CountryPickerThemeData
- minimal → const CountryPickerThemeData
- purple → const CountryPickerThemeData