Country class
Represents a country with its ISO code, flag emoji, and phone code
Constructors
Properties
- code β String
-
ISO country code (e.g., 'US', 'RU', 'GB')
final
- flag β String
-
Country flag emoji (e.g., 'πΊπΈ', 'π·πΊ', 'π¬π')
final
- hashCode β int
-
The hash code for this object.
no setteroverride
- phoneCode β String
-
Phone dialing code (e.g., '+1', '+7', '+44')
final
- runtimeType β Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getDisplayName(
BuildContext context) β String - Get the localized display name for this country
-
noSuchMethod(
Invocation invocation) β dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) β String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) β bool -
The equality operator.
override